==> rheolef_7.1.orig.tar.gz: rheolef-7.1/main/tst/bamg2geo_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/main/tst"}
BINDIR="../bin"
SBINDIR="../sbin"
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test x"${QD_EXT}" != x""; then
  echo "      not yet (skiped when QD lib is active)"
  exit 0
fi

status=0

# commands that generates .bamg files
# bamg -g square.bamgcad -o square_t_bamg.bamg
# bamg -thetaquad 60 -g square.bamgcad -o square_tq_bamg.bamg
# bamg -2q -thetaquad 30 -g square.bamgcad -o square_q_bamg.bamg

dmn="${SRCDIR}/square.dmn"
L="
square_t_bamg
square_q_bamg
square_tq_bamg
"
for geo in $L; do
  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}.geo - >/dev/null"
  if test $? -ne 0; then status=1; fi
done

# ----------------------------------------------------
# with vertex domains
# ----------------------------------------------------
dmn="${SRCDIR}/square_vertex_dom.dmn"
L="
square_t_bamg
"
for geo in $L; do
  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}_vertex_dom.geo - >/dev/null"
  if test $? -ne 0; then status=1; fi
done

exit $status

==> rheolef_7.2.orig.tar.gz: rheolef-7.2/main/tst/bamg2geo_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/main/tst"}
BINDIR="../bin"
SBINDIR="../sbin"
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test x"${QD_EXT}" != x""; then
  echo "      not yet (skiped when QD lib is active)"
  exit 0
fi

status=0

# commands that generates .bamg files
# bamg -g square.bamgcad -o square_t_bamg.bamg
# bamg -thetaquad 60 -g square.bamgcad -o square_tq_bamg.bamg
# bamg -2q -thetaquad 30 -g square.bamgcad -o square_q_bamg.bamg

# square-swap : boundary is defined in bamg with inward normal
# then there are minus sign on the boundary domains

dmn="${SRCDIR}/square.dmn"
L="
square_t_bamg
square_q_bamg
square_tq_bamg
square-swap
"
for geo in $L; do
  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}.geo - >/dev/null"
  if test $? -ne 0; then status=1; fi
done

# ----------------------------------------------------
# with vertex domains
# ----------------------------------------------------
dmn="${SRCDIR}/square_vertex_dom.dmn"
L="
square_t_bamg
"
for geo in $L; do
  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}_vertex_dom.geo - >/dev/null"
  if test $? -ne 0; then status=1; fi
done

exit $status
